autowisp.database.data_model.step_dependencies module — AutoWISP documentation

# autowisp.database.data_model.step_dependencies module

## Class Inheritance Diagram

Define class to specify dependencies between steps.

class autowisp.database.data_model.step_dependencies.StepDependencies(**kwargs)

  Bases: `DataModelBase`

  The table describing the prerequisites for a step to run

  __str__()

    Describe the dependency.

  blocked_image_type_id

    The image type for which this prerequisite applies.

  blocked_imtype
  blocked_step
  blocked_step_id

    The step for which this prerequisite applies.

  blocking_image_type_id

    The image type for which the prerequisite step must be completed.

  blocking_imtype
  blocking_step
  blocking_step_id

    The step which must be completed before the blocked step can begin.

  id

    A unique identifier for each row.

  timestamp

    When record was last changed